@@ -1,14 +1,18 @@
-#!/usr/bin/env perl
+undef $VERSION;
 package Bio::RetrieveAssemblies;
-$Bio::RetrieveAssemblies::VERSION = '1.1.2';
+$Bio::RetrieveAssemblies::VERSION = '1.1.4';
 use Moose;
+use Bio::Perl 1.006924; # force BioPerl to be picked up
 use Getopt::Long qw(GetOptionsFromArray);
 use Bio::RetrieveAssemblies::WGS;
 use Bio::RetrieveAssemblies::AccessionFile;
+with('Bio::RetrieveAssemblies::LoggingRole');
 
 # ABSTRACT: Download assemblies from GenBank
 
 
+
+
 has 'search_term'      => ( is => 'rw', isa => 'Str' );
 has 'output_directory' => ( is => 'rw', isa => 'Str', default => 'downloaded_files' );
 has 'file_type'        => ( is => 'rw', isa => 'Str', default => 'genbank' );
@@ -20,7 +24,7 @@ has 'script_name'      => ( is => 'ro', isa => 'Str', required => 1 );
 
 sub BUILD {
     my ($self) = @_;
-    my ( $help, $file_type, $output_directory, $organism_type,$query,$annotation );
+    my ( $help, $file_type, $output_directory, $organism_type,$query,$annotation,$verbose,$cmd_version );
     GetOptionsFromArray(
         $self->args,
         'p|organism_type=s'    => \$organism_type,
@@ -28,8 +32,16 @@ sub BUILD {
         'o|output_directory=s' => \$output_directory,
         'q|query=s'            => \$query,
         'a|annotation'         => \$annotation,
+		'v|verbose'            => \$verbose,
+		'version'              => \$cmd_version,
         'h|help'               => \$help,
     );
+	
+	if( $cmd_version)
+	{
+		print $self->_version();
+		exit();
+	}
 
     if ( $help || @{ $self->args } == 0 ) {
         print $self->usage_text();
@@ -41,10 +53,29 @@ sub BUILD {
     $self->organism_type($organism_type)       if ($organism_type);
     $self->query($query)                       if ($query);
     $self->annotation($annotation)             if ($annotation);
+	
+    if ( defined($verbose) ) {
+        $self->verbose($verbose);
+        $self->logger->level(10000);
+    }
 
     $self->search_term( $self->args->[0] );
 }
 
+sub _version
+{
+	my ($self) = @_;
+	if(defined(Bio::RetrieveAssemblies->VERSION))
+	{
+	   return Bio::RetrieveAssemblies->VERSION ."\n";
+    }
+	else
+	{
+	   return "x.y.z\n";
+	}
+}
+
+
 sub usage_text {
     my ($self) = @_;
 
@@ -75,6 +106,9 @@ sub usage_text {
     
 	# Search for a different category, VRT/INV/PLN/MAM/PRI/ENV (default is BCT)
 	retrieve_assemblies -p MAM Canis 
+	
+	# Verbose output
+	retrieve_assemblies -v Salmonella
 
 	# This message 
     retrieve_assemblies -h 
@@ -85,13 +119,19 @@ USAGE
 sub download {
     my ($self) = @_;
 
-    my $wgs_assemblies = Bio::RetrieveAssemblies::WGS->new( query => $self->query, organism_type => $self->organism_type, search_term => $self->search_term );
+    $self->logger->info("Starting download from NCBI");
+	$self->logger->info("query:\t".$self->query);
+	$self->logger->info("organism_type:\t".$self->organism_type);
+	$self->logger->info("search_term:\t".$self->search_term);
+    my $wgs_assemblies = Bio::RetrieveAssemblies::WGS->new( query => $self->query, organism_type => $self->organism_type, search_term => $self->search_term, logger => $self->logger, verbose => $self->verbose );
 
     for my $accession ( sort keys %{ $wgs_assemblies->accessions() } ) {
         my $accession_file = Bio::RetrieveAssemblies::AccessionFile->new(
             accession        => $accession,
             file_type        => $self->file_type,
-            output_directory => $self->output_directory
+            output_directory => $self->output_directory,
+			logger           => $self->logger, 
+			verbose          => $self->verbose
         );
         $accession_file->download_file();
     }
@@ -114,7 +154,7 @@ Bio::RetrieveAssemblies - Download assemblies from GenBank
 
 =head1 VERSION
 
-version 1.1.2
+version 1.1.4
 
 =head1 SYNOPSIS
 
