@@ -1,5 +1,5 @@
 package Bio::RetrieveAssemblies::WGS;
-$Bio::RetrieveAssemblies::WGS::VERSION = '1.1.2';
+$Bio::RetrieveAssemblies::WGS::VERSION = '1.1.4';
 use Moose;
 use Bio::RetrieveAssemblies::RefWeak;
 with('Bio::RetrieveAssemblies::RemoteSpreadsheetRole');
@@ -19,9 +19,11 @@ has 'url'                 => ( is => 'ro', isa => 'Str',     lazy => 1, builder
 has 'accessions'          => ( is => 'ro', isa => 'HashRef', lazy => 1, builder => '_build_accessions' );
 has '_refweak_accessions' => ( is => 'ro', isa => 'HashRef', lazy => 1, builder => '_build__refweak_accessions' );
 
+
 sub _build__refweak_accessions {
     my ($self) = @_;
-    return Bio::RetrieveAssemblies::RefWeak->new()->accessions();
+	$self->logger->info("Downloading list of bad assembly accession numbers from RefWeak");
+    return Bio::RetrieveAssemblies::RefWeak->new(logger => $self->logger, verbose => $self->verbose)->accessions();
 }
 
 sub _build_url {
@@ -69,7 +71,7 @@ Bio::RetrieveAssemblies::WGS - Get all the WGS assemblies
 
 =head1 VERSION
 
-version 1.1.2
+version 1.1.4
 
 =head1 SYNOPSIS
 
